#include "SiteServer.h"

#include "Sensors/TemperatureSensor.h"

namespace Passer {
namespace Control {

SiteServer::SiteServer(int port) {
  this->name = "Site Server";

  this->ipAddress = "0.0.0.0";
  this->port = port;

  this->participants.push_back(this);

  SetupUDP(port, ipAddress, 0);
}

void SiteServer::Update(unsigned long currentTimeMs) {
  this->ReceiveUDP();
  Thing::UpdateAll(currentTimeMs);
}

void SiteServer::Process(Participant *sender, ClientMsg *msg) {
  if (msg->networkId == 0) {
    std::cout << this->name << " received New Client -> " << sender->ipAddress
              << "  " << (int)sender->networkId << "\n";
    NetworkIdMsg *msg = new NetworkIdMsg(sender->networkId);
    sender->Send(msg);
    delete msg;
  }
}

void SiteServer::Process(Participant *sender, NetworkIdMsg *msg) {}

void SiteServer::Process(ThingMsg *msg) {

  Thing *thing = Thing::Get(msg->networkId, msg->thingId);
  if (thing == nullptr) {
    switch ((Thing::Type)msg->thingType) {
    case Thing::Type::TemperatureSensor:
      new TemperatureSensor(msg->networkId, msg->thingId);
      break;
    default:
      new Thing(this, msg->networkId, msg->thingId,
                (Thing::Type)msg->thingType);
      break;
    }
  }
}

} // namespace Control
} // namespace Passer
